#delimit cr             /* Set end of line delimiter (this is the default).     */
version 14                      /* Declare version for forward compatibility.   */
set more off                                    /* Get rid of -MORE- in display.*/
  quietly log                                   /* Close log file if open.      */
  local logon = r(status)
  if "`logon'" == "on" {
        log close
        }
log using comp01basic.log, text replace         /* Open new log file.   */

/*      ******************************************************************        */
/*      File Name:      comp01basic.do                                            */
/*      Date:           January 6, 2020                                           */
/*      Author:         Frederick J. Boehmke                                      */
/*      Purpose:        Basic data manipulation commands in Stata.                */
/*      Input File:     https://myweb.uiowa.edu/fboehmke/stata2020-01/comp01.dta, */
/*                      https://myweb.uiowa.edu/fboehmke/stata2020-01/comp01.csv, */
/*      Output File:    comp01basic.log,                                          */
/*                      comp01basic.dta,                                          */
/*                      comp01basic-version13.dta,                                */
/*                      comp01basic.csv,                                          */
/*                      comp01basic.dct                                           */
/*      ******************************************************************        */


        /************************************************/
        /* Opening data in various ways.                */
        /************************************************/


                  /* Open Stata format data and clear any open data. */

use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp01.dta, clear

                /* Basic data characteristics. */

  describe
  summarize
  summarize, detail

                  /* Open comma-separated data with varaible names in row 1, clearing any open data. */

import delimited using https://myweb.uiowa.edu/fboehmke/stata2020-01/comp01.csv, clear ///
        delimiter(",") case(preserve) varnames(1)

  describe
  summarize
  summarize, detail

        /************************************************/
        /* Basic data summaries and tabulations.        */
        /************************************************/

use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp01.dta, clear 

describe
summarize
summarize, detail

tabstat female race educ income natlec turnout pid3_p, statistics(mean sd min max N) ///
columns(statistics)

tab1 state female race natlec

tab1 female-educ              /* Illustrate varlist. */

tab natlec female
tab natlec female, row
tab natlec female, row nofreq

	/* Label variables to see how it can help.      */

label variable natlec         "Economic Conditions"
label variable female         "Female"

tab natlec female, row nofreq

	/* Label values to see how it can help.         */
	
label define female 0 Male 1 Female

label values female female

tab natlec female, row nofreq

table female, c(mean natlec sd natlec)

	/* Illustrate missing values behavior. */

bysort income: sum natlec
tabulate income, summarize(natlec) missing

summarize natlec if income == 1
summarize natlec if income <  8
summarize natlec if income >= 8
summarize natlec if income >= 15      /* Missing values are infinity. */
summarize natlec if income >= 15 & !missing(income)


        /************************************************/
        /* Now do some graphical summaries of the data. */
        /************************************************/


hist natlec

twoway hist natlec              /* twoway is suite of graph commands. */

twoway hist natlec, scheme(s1color) ///
        title(Distribution of Retrospective National Economic Evaluations)

twoway hist natlec, scheme(s1color) by(female)

twoway hist natlec, scheme(s1color) by(female, ///
          title(Distribution of Retrospective National Economic Evaluations))

          
        /************************************************/
        /* Basic commands for labeling and saving data. */
        /************************************************/


label data "Data Science Institute (Boehmke, 2020)"

  label variable natlec         "Economic Conditions"
  label variable female         "Female"

        compress                /* Stores variables more efficiently. */

        sort state              /* Sort the data by US state of residence. */
  
  save comp01basic, replace
  saveold comp01basic-version13, replace version(13)

  export delimited using comp01basic.xlsx, replace 
  outfile using comp01basic, nolabel replace dictionary
  
                /* Open fixed format data we just created and clear any open data. */

infile using comp01basic, clear

  describe
  summarize
  summarize, detail


        /****************************************/
        /* Now do some basic data analysis.     */
        /****************************************/

                /* Difference in means test. */
        
ttest natlec, by(female)

                /* Difference in marginal frequencies test. */
        
tabulate natlec female                          /* Raw frequencies. */
tabulate natlec female, col                     /* Add column percentages. */
tabulate natlec female, col nofreq              /* Remove raw frequencies. */
tabulate natlec female, col nofreq chi2         /* Report chi2 text. */
tabulate natlec female, col nofreq all          /* Report all tests. */

regress natlec female                           /* Linear regression. */
regress natlec female income

logit turnout natlec female income              /* Binary outcome variable. */

ologit natlec female income                     /* Ordered outcome variable. */

mlogit pid3_p female income, base(2)            /* Unordered outcome variable. */

mixed natlec female income || state:            /* MLM/HLM with random effects by US state. */
mixed natlec female income || state: income     /* MLM/HLM with random effects and random coefficient on income by US state. */

log close
