version 14
clear
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
        log close 
        }
log using comp03reshape_merge, text replace

/*      ************************************************************************        */
/*      Author:         Frederick J. Boehmke                                            */
/*      Date:           January 6, 2020                                                 */
/*      File:           comp03reshape_merge.do                                          */
/*      Purpose:        Reshape and merge data sets.                                    */
/*      Input file:     https://myweb.uiowa.edu/fboehmke/stata2020-01/comp03-pop.dta    */
/*                      https://myweb.uiowa.edu/fboehmke/stata2020-01/comp03-inc.dta    */
/*      Output File:    comp03reshape_merge.dta,                                        */
/*                      comp03reshape_merge.log                                         */
/*      Requires:                                                                       */
/*      ************************************************************************        */


        /**********************************************************************/
        /* Read in and reshape the population data to state-pop observations. */
        /**********************************************************************/


use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp03-pop, clear

        summarize pop*

reshape long pop, i(state_name) j(year)

        table year, c(mean pop)                 /* This should match what we had prior. */

                /* Even easier to verify our totals now. */

table year if state_fips==0, c(sum pop) format(%9.0f) row                       /* US total. */
table year if state_fips>=1 & state_fips<=56, c(sum pop) format(%9.0f) row      /* 50 states + DC. */
table year if state_fips>=1 & state_fips<=56, c(sum pop) cellwidth(10) format(%9.0f) row

                /* Save the data so we can open and clean the next data set. */
  
save comp03reshape_merge, replace
  
  
        /******************************************************************/
        /* Read in the income data set for the same period and then merge.*/
        /******************************************************************/

        
use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp03-inc, clear

reshape long pcpi, i(state_fips) j(year)
        
                /* Drop unneeded observations. */

  drop if inlist(state_name, "Great Lakes", "Mideast", "Southwest", "Southeast", "Rocky Mountain", ///
        "New England", "Mideast", "Far West", "Plains")

                /* Now merge by year and state with the population data we saved above. */
                /* Assert means issue a warning if any deviation from match master using. */
        
  merge 1:1 state_fips year using comp03reshape_merge, keep(match master using) assert(match) generat(_merge_pcpi)
  
        tab _merge_pcpi

                /* Check structure of the data to make sure it's what we expect. */
  
  tab year, missing
  tab state_name, missing
  
  
        /********************************************************************************/
        /* Run the duplicates command to make sure we didn't mess up our merge.         */
        /********************************************************************************/

        
duplicates report                       /* This will check out. */
duplicates report state_name year       /* This makes sure we have one observation per state and year. */

duplicates report state_name            /* This will show 76 copies for each state. */

duplicates example state_name           /* This shows some examples of the duplicates. */

  
        /************************************************************************/
        /* Now do a many-to-one merge to adjust income for annual inflation.    */
        /************************************************************************/

        
merge m:1 year using https://myweb.uiowa.edu/fboehmke/stata2020-01/comp03-cpi, keep(match master) nogenerate

  generat rpcpi = pcpi*cpi83
  
                /* A table and a graph to show the differences. */
  
        table year if state_name == "United States", c(mean pcpi mean rpcpi) format(%9.0f)
        
        graph bar pcpi rpcpi if state_name == "United States", over(year, label(nolabel))

        
        /****************************************/
        /* Indicate CSTS nature of the data.    */
        /****************************************/
        
        
xtset state_fips year

                /* Illustrate use of lag operator to get national annual population growth. */
        
regress pop l.pop if state_name == "United States"
        
        
        /****************************************/
        /* Label the data and variables.        */
        /****************************************/
        
        
label data "State population and Income, 1929-2005 (Boehmke, 2020)"
   
   drop _merge_pcpi
   
        order state* year pop pcpi              /* Order the variables. */
        sort state_name year                    /* Order the data. */
  
        label variable pop              "State Population"
        label variable pcpi             "State Income per Capita (Nominal)"
        label variable rpcpi            "State Income per Capita (Inflation adjusted)"
  
        compress                                /* Stores the data more efficiently. */ 
  
  save comp03reshape_merge, replace

        
        /****************************************/
        /* Illustrate collapse command.         */
        /****************************************/
        

                /* First, here is total population in the US, two different ways. */
        
table year if state_name == "United States", c(mean pop) format(%9.0f)
table year if state_name != "United States", c(sum pop) format(%9.0f)
        
                /* Now let's create a data with annual total population and its standard deviation. */
        
drop if state_name == "United States"           /* Pretend we don't have this. */

collapse (sum) pop (sd) pop_sd=pop, by(year)

table year, c(sum pop) format(%9.0f)            /* Of course it matches. */

list year pop pop_sd                            /* But this all we have now. */
        
log close
clear
