version 14
clear
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
        log close 
        }
log using comp06graph, text replace

/*      **************************************************************************      */
/*      Author:         Frederick J. Boehmke                                            */
/*      Date:           January 6, 2020                                                 */
/*      File:           comp06graph.do                                                  */
/*      Purpose:        Basic graphing examples and options in Stata.                   */
/*      Input File:     https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph.dta   */
/*      Output File:    comp06graph.log,                                                */
/*                      comp06graph-ideology.gph,                                       */
/*                      comp06graph-ideology.png                                        */
/*      **************************************************************************      */

        /****************************************/
        /* Open up cleaned up ANES data.        */
        /****************************************/


use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear
        
  describe
        
  summarize
  tab1 _all


        /************************************************/
        /* Do some basic summary graphs.                */
        /************************************************/

        
foreach var of varlist _all {

  histogram `var'

  }
  
graph box ideology

graph box female-ideology

                /* Graph and save, then illustrate how to export to other formats. */

graph box ideology, scheme(s2mono) over(educ) saving(comp06graph-ideology, replace)

  graph export comp06graph-ideology.png, replace width(2000)   /* Use -width- with png for better quality. */


        /************************************************/
        /* Now collapse to show how to compare many     */
        /* variables at once.                           */
        /************************************************/


collapse (mean) age-ideology, by(year)
        
graph matrix age-ideology

                /* Let's write a loop to keep the variable labels. */

use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear

                /* Capture the variable labels. */

foreach var of varlist _all {

  local `var'_lab : variable label `var'
  
  }
        
collapse (mean) age-ideology, by(year)
        
                /* Now apply the variable labels to the collapsed variables. */

foreach var of varlist _all {

  label variable `var' "``var'_lab'"
  
  }
        
        
graph matrix age-ideology

        
        /************************************************/
        /* Compare relationship between two variables.  */
        /************************************************/


use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear

twoway scatter ideology educ

twoway sunflower ideology educ if year==1972, by(female) binwidth(1)

graph dot ideology, over(educ) ylabel(1/7)

graph dot income, over(year) ylabel(1/5)

  
graph dot ideology partyid, over(year) ylabel(1/7)


qqplot ideology partyid

twoway kdensity ideology || kdensity partyid

twoway lowess ideology partyid


graph bar partyid, over(ideology) horiz

graph dot partyid, over(ideology) ylabel(1/7)


graph bar (sd) partyid, over(ideology) horiz

graph dot (sd) partyid, over(ideology) horiz


graph dot (mean) partyid (sd) partyid, over(ideology) horiz ylabel(1/7)


graph dot (sd) ideology partyid, over(year) ylabel(1/7)

graph dot (sd) ideology partyid (mean) ideology partyid, over(year) ylabel(1/7)


twoway scatter ideology partyid, jitter(8)

twoway mspline ideology partyid


        /************************************************/
        /* Now collapse to show how that can help with  */
        /* ordinal or nominal variables.                */
        /************************************************/
		

collapse (mean) vote (count) numobs=female numvote=vote, by(ideology partyid)
        
  label variable vote           "Proportion that Voted"
  label variable ideology       "Self-Reported Ideology"
  label variable partyid        "Partisan Identification"
        
twoway scatter ideology partyid

twoway scatter ideology partyid [aw=numobs]

twoway scatter ideology partyid, msymbol(none) mlabel(numobs) mlabposition(0)


twoway scatter ideology partyid [fw=vote]


twoway lfit ideology partyid [aw=numobs]

twoway qfit ideology partyid [aw=numobs]


twoway lfitci ideology partyid [aw=numobs]

twoway qfitci ideology partyid [aw=numobs]


        /************************************************/
        /* Show how different graphs can affect         */
        /* interpretation.                              */
        /************************************************/


twoway scatter ideology partyid

twoway scatter ideology partyid [fw=vote]

twoway scatter vote ideology

twoway scatter vote partyid


twoway scatter vote partyid, by(ideology)

twoway scatter vote partyid, by(ideology, total)

twoway scatter vote ideology, by(partyid, total)

                /* We can include plots for when ideology is */
				/* missing and one that combines all categories. */

twoway dropline vote ideology, by(partyid, total missing imargin(tiny)) name(graph1, replace)

twoway area vote ideology, by(partyid, total missing imargin(tiny)) name(graph2, replace)

twoway spike vote ideology, by(partyid, total missing imargin(tiny)) name(graph3, replace)

twoway line vote ideology, by(partyid, total missing imargin(tiny)) name(graph4, replace)

twoway connected vote ideology, by(partyid, total missing imargin(tiny)) name(graph5, replace)

twoway bar vote ideology, by(partyid, total missing imargin(tiny)) name(graph6, replace)

                /* Close all of those graph windows to clean things up. */
				
graph close _all

                /* Now illustrate how to combine multiple graphs into one. */

graph combine graph1 graph2 graph3 graph4 graph5 graph6


graph combine graph1 graph2 graph3 graph4 graph5 graph6, ///
        rows(2) cols(3) imargin(tiny)


twoway scatter vote ideology, by(partyid, total) ///
  ||    qfit vote ideology [aw=numobs]


twoway scatter vote ideology, by(partyid, total legend(off)) ///
  ||    qfit vote ideology [aw=numobs]


twoway scatter vote partyid, by(ideology, total legend(off) l1title(Proportion Voting)) ///
  ||    qfit vote partyid [aw=numobs]


twoway connected vote partyid if ideology == 1 ///
  ||    connected vote partyid if ideology == 2 ///
  ||    connected vote partyid if ideology == 3 ///
  ||    connected vote partyid if ideology == 4 ///
  ||    connected vote partyid if ideology == 5 ///
  ||    connected vote partyid if ideology == 6 ///
  ||    connected vote partyid if ideology == 7


twoway line vote partyid if ideology == 1 ///
  ||    line vote partyid if ideology == 2 ///
  ||    line vote partyid if ideology == 3 ///
  ||    line vote partyid if ideology == 4 ///
  ||    line vote partyid if ideology == 5 ///
  ||    line vote partyid if ideology == 6 ///
  ||    line vote partyid if ideology == 7


        /************************************************/
        /* Overlay some graphs.                         */
        /************************************************/

        
twoway scatter ideology partyid [aw=numobs] || lfit ideology partyid [aw=numobs]

twoway scatter ideology partyid [aw=numobs] || qfit ideology partyid [aw=numobs]

twoway scatter ideology partyid [aw=numobs] || qfitci ideology partyid [aw=numobs]

twoway scatter ideology partyid [aw=numobs] || qfitci ideology partyid [aw=numobs],  ///
        ciplot(rspike)

twoway scatter ideology partyid [aw=numobs] || qfitci ideology partyid [aw=numobs], ///
        ciplot(rline)


        /************************************************/
        /* Show graphs that plot ranges, etc.           */
        /************************************************/


use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear

  generat vote_hs = voted if educ <  4
  generat vote_cg = voted if educ >= 4

  collapse (mean) vote_hs vote_cg (count) numobs=female, by(ideology partyid)

        label variable vote_hs  "Proportion that Voted (No College)"
        label variable vote_hs  "Proportion that Voted (College or More)"
        label variable ideology "Self-Reported Ideology"
        label variable partyid  "Partisan Identification"
        
twoway scatter vote* ideology, by(partyid, total)

twoway connected vote* ideology, by(partyid, total)


twoway qfit vote_hs ideology [aw=numobs] ///
  ||    qfit vote_cg ideology [aw=numobs], by(partyid, total l1title(Proportion Voting))

        
twoway rscatter vote* ideology, by(partyid)

twoway rconnected vote* ideology, by(partyid)

twoway rline vote* ideology, by(partyid, total)

twoway rspike vote* ideology, by(partyid)

twoway rarea vote* ideology, by(partyid)

twoway rcap vote* ideology, by(partyid)

twoway rbar vote* ideology, by(partyid)

                /* Graph proportion partisans over time. */

use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear

  generat pid_dem = (partyid <= 3)
  generat pid_rep = (partyid >= 5) & !missing(partyid)
  generat pid_ind = (partyid == 4)
  
  generat pid_str = pid_dem + pid_rep
  
                /* Run it again without independents who lean. */
  
  generat pid_dem_nolean = (partyid <= 2)
  generat pid_rep_nolean = (partyid >= 6) & !missing(partyid)
  generat pid_ind_nolean = (partyid < 6 & partyid > 2)
 
  generat pid_str_nolean = pid_dem_nolean + pid_rep_nolean
  
  graph dot pid_dem_nolean pid_rep_nolean pid_ind_nolean, over(year)
  graph dot pid_dem pid_rep pid_ind, over(year) ///
	legend(label(1 "Democrats") label(2 "Republicans") label(3 "Independents") rows(1) order(3 2 1))

        /* Now in black and white with symbols instead of colors. */	
	
  graph dot pid_dem pid_rep pid_ind, scheme(s2mono) over(year) ///
        marker(1, msymbol(O) mcolor(black)) marker(2, msymbol(S) mcolor(black)) marker(3, msymbol(T) mcolor(black)) ///
	legend(label(1 "Democrats") label(2 "Republicans") label(3 "Independents") rows(1) order(3 2 1))
  
  
        /************************************************/
        /* Show graphs that connect points in order.    */
        /************************************************/


use https://myweb.uiowa.edu/fboehmke/stata2020-01/comp06graph, clear

  collapse (mean) ideology voted, by(year)
  
  tsset year
  
                /* This allows us to see a bivariate relationship. */
  
twoway scatter ideology voted

                /* This allows us to see how it changes over time. */
  
twoway pcarrow L2.ideology L2.voted ideology voted, msize(3)

                /* Add some features to aid interpretation. */
  
twoway pcarrow L2.ideology L2.voted ideology voted,  ///
        msize(3)  ///
  ||    scatter ideology voted if year==1972, ///
        mcolor(dknavy) msymbol(O) mlabel(year) mlabcolor(dknavy)
        
twoway pcarrow L2.ideology L2.voted ideology voted,  ///
        msize(3)  ///
  ||    scatter ideology voted if year==1972, ///
        mcolor(dknavy) msymbol(O) mlabel(year) mlabcolor(dknavy) ///
  ||    scatter ideology voted if year==2004, ///
        mcolor(dknavy) msymbol(O) mlabel(year) mlabcolor(dknavy) ///
        xtitle(Turnout) ytitle(Ideology) ///
        legend(off)

log close
clear
